Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1071)

Unified Diff: chrome/browser/ui/crypto_module_password_dialog.h

Issue 6580058: NSS: Unlock crypto devices when populating cert manager. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review changes Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/crypto_module_password_dialog.h
diff --git a/chrome/browser/ui/crypto_module_password_dialog.h b/chrome/browser/ui/crypto_module_password_dialog.h
index a6d9052c9e14dce8649324f25df323e10987411e..199120e137ada912aa1c94593ec30f541be625eb 100644
--- a/chrome/browser/ui/crypto_module_password_dialog.h
+++ b/chrome/browser/ui/crypto_module_password_dialog.h
@@ -7,8 +7,10 @@
#pragma once
#include <string>
+#include <vector>
#include "base/callback.h"
+#include "base/ref_counted.h"
namespace base {
class CryptoModuleBlockingPasswordDelegate;
@@ -16,6 +18,7 @@ class CryptoModuleBlockingPasswordDelegate;
namespace net {
class CryptoModule;
+typedef std::vector<scoped_refptr<CryptoModule> > CryptoModuleList;
class X509Certificate;
}
@@ -26,6 +29,7 @@ enum CryptoModulePasswordReason {
kCryptoModulePasswordKeygen,
kCryptoModulePasswordCertEnrollment,
kCryptoModulePasswordClientAuth,
+ kCryptoModulePasswordListCerts,
kCryptoModulePasswordCertImport,
kCryptoModulePasswordCertExport,
};
@@ -49,13 +53,13 @@ base::CryptoModuleBlockingPasswordDelegate*
CryptoModulePasswordReason reason,
const std::string& server);
-// Asynchronously unlock |module|, if necessary. |callback| is called when done
-// (regardless if module was successfully unlocked or not). Should only be
-// called on UI thread.
-void UnlockSlotIfNecessary(net::CryptoModule* module,
- browser::CryptoModulePasswordReason reason,
- const std::string& server,
- Callback0::Type* callback);
+// Asynchronously unlock |modules|, if necessary. |callback| is called when
+// done (regardless if any modules were successfully unlocked or not). Should
+// only be called on UI thread.
+void UnlockSlotsIfNecessary(const net::CryptoModuleList& modules,
+ browser::CryptoModulePasswordReason reason,
+ const std::string& server,
+ Callback0::Type* callback);
// Asynchronously unlock the |cert|'s module, if necessary. |callback| is
// called when done (regardless if module was successfully unlocked or not).

Powered by Google App Engine
This is Rietveld 408576698